part of persistent_bottom_nav_bar;

class BottomNavStyle12 extends StatefulWidget {
  final NavBarEssentials navBarEssentials;

  BottomNavStyle12({
    Key key,
    this.navBarEssentials = const NavBarEssentials(items: null),
  });

  @override
  _BottomNavStyle12State createState() => _BottomNavStyle12State();
}

class _BottomNavStyle12State extends State<BottomNavStyle12>
    with TickerProviderStateMixin {
  List<AnimationController> _animationControllerList;
  List<Animation<Offset>> _animationList;

  int _lastSelectedIndex;
  int _selectedIndex;

  @override
  void initState() {
    super.initState();
    _lastSelectedIndex = 0;
    _selectedIndex = 0;
    _animationControllerList = List<AnimationController>();
    _animationList = List<Animation<Offset>>();

    for (int i = 0; i < widget.navBarEssentials.items.length; ++i) {
      _animationControllerList.add(AnimationController(
          duration: widget.navBarEssentials.itemAnimationProperties?.duration ??
              Duration(milliseconds: 400),
          vsync: this));
      _animationList.add(Tween(
              begin: Offset(0, widget.navBarEssentials.navBarHeight),
              end: Offset(0, 0.0))
          .chain(CurveTween(
              curve: widget.navBarEssentials.itemAnimationProperties?.curve ??
                  Curves.ease))
          .animate(_animationControllerList[i]));
    }

    WidgetsBinding.instance.addPostFrameCallback((_) {
      _animationControllerList[_selectedIndex].forward();
    });
  }

  Widget _buildItem(PersistentBottomNavBarItem item, bool isSelected,
      double height, int itemIndex) {
    return widget.navBarEssentials.navBarHeight == 0
        ? SizedBox.shrink()
        : AnimatedBuilder(
            animation: _animationList[itemIndex],
            builder: (context, child) => Container(
              width: 150.0,
              height: height,
              child: Container(
                alignment: Alignment.center,
                height: height,
                child: Column(
                  mainAxisAlignment: MainAxisAlignment.center,
                  crossAxisAlignment: CrossAxisAlignment.center,
                  children: <Widget>[
                    Expanded(
                      child: IconTheme(
                        data: IconThemeData(
                            size: item.iconSize,
                            color: isSelected
                                ? (item.activeColorAlternate == null
                                    ? item.activeColor
                                    : item.activeColorAlternate)
                                : item.inactiveColor == null
                                    ? item.activeColor
                                    : item.inactiveColor),
                        child: item.icon,
                      ),
                    ),
                    item.title == null
                        ? SizedBox.shrink()
                        : Transform.translate(
                            offset: _animationList[itemIndex].value,
                            child: AnimatedContainer(
                              duration: widget.navBarEssentials
                                      .itemAnimationProperties?.duration ??
                                  Duration(milliseconds: 400),
                              height: 5.0,
                              width: 5.0,
                              decoration: BoxDecoration(
                                  borderRadius: BorderRadius.circular(100.0),
                                  color: isSelected
                                      ? (item.activeColorAlternate == null
                                          ? item.activeColor
                                          : item.activeColorAlternate)
                                      : Colors.transparent),
                            ),
                          ),
                  ],
                ),
              ),
            ),
          );
  }

  @override
  void dispose() {
    for (int i = 0; i < widget.navBarEssentials.items.length; ++i) {
      _animationControllerList[i].dispose();
    }
    super.dispose();
  }

  @override
  Widget build(BuildContext context) {
    if (widget.navBarEssentials.items.length !=
        _animationControllerList.length) {
      _animationControllerList = List<AnimationController>();
      _animationList = List<Animation<Offset>>();

      for (int i = 0; i < widget.navBarEssentials.items.length; ++i) {
        _animationControllerList.add(AnimationController(
            duration:
                widget.navBarEssentials.itemAnimationProperties?.duration ??
                    Duration(milliseconds: 400),
            vsync: this));
        _animationList.add(Tween(
                begin: Offset(0, widget.navBarEssentials.navBarHeight),
                end: Offset(0, 0.0))
            .chain(CurveTween(
                curve: widget.navBarEssentials.itemAnimationProperties?.curve ??
                    Curves.ease))
            .animate(_animationControllerList[i]));
      }
    }
    if (widget.navBarEssentials.selectedIndex != _selectedIndex) {
      _lastSelectedIndex = _selectedIndex;
      _selectedIndex = widget.navBarEssentials.selectedIndex;
      _animationControllerList[_selectedIndex].forward();
      _animationControllerList[_lastSelectedIndex].reverse();
    }
    return Container(
      width: double.infinity,
      height: widget.navBarEssentials.navBarHeight,
      padding: EdgeInsets.only(
          left: widget.navBarEssentials.padding?.left ??
              MediaQuery.of(context).size.width * 0.04,
          right: widget.navBarEssentials.padding?.right ??
              MediaQuery.of(context).size.width * 0.04,
          top: widget.navBarEssentials.padding?.top ??
              widget.navBarEssentials.navBarHeight * 0.15,
          bottom: widget.navBarEssentials.padding?.bottom ??
              widget.navBarEssentials.navBarHeight * 0.12),
      child: Row(
        mainAxisAlignment: MainAxisAlignment.spaceAround,
        crossAxisAlignment: CrossAxisAlignment.center,
        children: widget.navBarEssentials.items.map((item) {
          int index = widget.navBarEssentials.items.indexOf(item);
          return Expanded(
            child: GestureDetector(
              onTap: () {
                if (widget.navBarEssentials.items[index].onPressed != null) {
                  widget.navBarEssentials.items[index].onPressed();
                } else {
                  if (index != _selectedIndex) {
                    _lastSelectedIndex = _selectedIndex;
                    _selectedIndex = index;
                    _animationControllerList[_selectedIndex].forward();
                    _animationControllerList[_lastSelectedIndex].reverse();
                  } else if (widget
                          .navBarEssentials.popScreensOnTapOfSelectedTab &&
                      widget.navBarEssentials.previousIndex == index) {
                    widget.navBarEssentials
                        .popAllScreensForTheSelectedTab(index);
                  }
                  widget.navBarEssentials.onItemSelected(index);
                }
              },
              child: Container(
                color: Colors.transparent,
                child: _buildItem(
                    item,
                    widget.navBarEssentials.selectedIndex == index,
                    widget.navBarEssentials.navBarHeight,
                    index),
              ),
            ),
          );
        }).toList(),
      ),
    );
  }
}
